Claw, Bimodal, Kurtotic, Outlier, Trimodal: Datasets
Description
A random sample of size 200 from the claw, bimodal, kurtotic, outlier and trimodal Gaussian density.Usage
data(claw)
data(bimodal)
data(kurtotic)
data(outlier)
data(trimodal)
newcommand
\CRANpkghref
http://CRAN.R-project.org/package=#1pkg
#1format
Numeric vector with length 200.source
Randomly generated a normal mixture with the function rnorMix in package nor1mix.Details
Generate 200 random numbers, distributed according to a normal mixture, using
rnorMix in package nor1mix.
## Claw density
claw <- rnorMix(n=200, MW.nm10)
plot(MW.nm10)
## Bimodal density
bimodal <- rnorMix(n=200, MW.nm7)
plot( MW.nm7)
## Kurtotic density
kurtotic <- rnorMix(n=200, MW.nm4)
plot(MW.nm4)
## Outlier density
outlier <- rnorMix(n=200, MW.nm5)
plot( MW.nm5)
## Trimodal density
trimodal <- rnorMix(n=200, MW.nm9)
plot(MW.nm9)References
Martin, M. (2013).
nor1mix: Normal (1-d) mixture models (S3 classes and methods).
Rpackage version 1.1-4.